# JSON Phenos to Dict - Package

This pacakge is specific for BIDS formatted data with JSON files.
Create a CSV or obtain a python dictionary for your desired subjects and phenotypes.

You can use this tool in the command line or in a python session.
If you specifically want a dictionary, import that package and invoke 'main' in a python session. You will be prompted for arguments: desired phenotypes, the filepath 'base' for your JSON files, and the name of the (optional) output csv.

For help, enter 'python consolidate\_json\_phenos.py -h' in the command line for the list of options.

More can be found here: [Marco-Nardin-GitHub](https://github.com/marconardin/csv-json-csv)
